#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['wgus']

package_data = \
{'': ['*']}

install_requires = \
['pydantic ==1.8.2',
 'pytest ==6.2.5',
 'aiohttp ==3.7.4.post0',
 'aiodns ==3.0.0',
 'cchardet ==2.1.7']

extras_require = \
{'test': ['pytest >=6.2.4,<7.0.0',
          'pytest-cov >=2.12.0,<4.0.0',
          'mypy ==0.910',
          'flake8 >=3.8.3,<4.0.0',
          'black ==21.9b0',
          'isort >=5.0.6,<6.0.0']}

setup(name='wgus',
      version='0.0.1',
      description='API for Wargaming Update Service (WGUS)',
      author='Renat Iliev',
      author_email='me@izeberg.ru',
      url='https://github.com/IzeBerg/python-wgus',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.9',
     )
